pub fn bridge_script(platform: &str, version: &str) -> StringExpand description
The script, with the current allowlist compiled into it.
platform is the value pp.native.platform reports; the generated shell
passes crate::Platform::current.
pub fn bridge_script(platform: &str, version: &str) -> StringThe script, with the current allowlist compiled into it.
platform is the value pp.native.platform reports; the generated shell
passes crate::Platform::current.